@@ -31,6 +31,7 @@ from joblib.test.common import with_multiprocessing
 from joblib.testing import (parametrize, raises, check_subprocess_call,
                             skipif, SkipTest, warns)
 
+from joblib.externals.loky.process_executor import TerminatedWorkerError
 
 from queue import Queue
 
@@ -530,6 +531,7 @@ def nested_function_outer(i):
 
 @with_multiprocessing
 @parametrize('backend', PARALLEL_BACKENDS)
+@pytest.mark.xfail(reason="https://github.com/joblib/loky/pull/255")
 def test_nested_exception_dispatch(backend):
     """Ensure errors for nested joblib cases gets propagated
 
@@ -808,7 +810,7 @@ def test_retrieval_context():
 
     with parallel_backend("retrieval") as (ba, _):
         Parallel(n_jobs=2)(
-            delayed(nested_call, check_pickle=False)(i)
+            delayed(nested_call)(i)
             for i in range(5)
         )
         assert ba.i == 1
@@ -1213,33 +1215,6 @@ def test_lambda_expression(backend):
     assert results == [i ** 2 for i in range(10)]
 
 
-def test_delayed_check_pickle_deprecated():
-    class UnpicklableCallable(object):
-
-        def __call__(self, *args, **kwargs):
-            return 42
-
-        def __reduce__(self):
-            raise ValueError()
-
-    with warns(DeprecationWarning):
-        f, args, kwargs = delayed(lambda x: 42, check_pickle=False)('a')
-    assert f('a') == 42
-    assert args == ('a',)
-    assert kwargs == dict()
-
-    with warns(DeprecationWarning):
-        f, args, kwargs = delayed(UnpicklableCallable(),
-                                  check_pickle=False)('a', option='b')
-        assert f('a', option='b') == 42
-        assert args == ('a',)
-        assert kwargs == dict(option='b')
-
-    with warns(DeprecationWarning):
-        with raises(ValueError):
-            delayed(UnpicklableCallable(), check_pickle=True)
-
-
 @with_multiprocessing
 @parametrize('backend', PROCESS_BACKENDS)
 def test_backend_batch_statistics_reset(backend):
@@ -1372,7 +1347,7 @@ def test_invalid_backend_hinting_and_constraints():
         # requiring shared memory semantics.
         Parallel(prefer='processes', require='sharedmem')
 
-    # It is inconsistent to ask explictly for a process-based parallelism
+    # It is inconsistent to ask explicitly for a process-based parallelism
     # while requiring shared memory semantics.
     with raises(ValueError):
         Parallel(backend='loky', require='sharedmem')
@@ -1468,8 +1443,18 @@ def test_thread_bomb_mitigation(backend):
     # saturating the operating system resources by creating a unbounded number
     # of threads.
     with parallel_backend(backend, n_jobs=2):
-        with raises(RecursionError):
+        with raises(BaseException) as excinfo:
             _recursive_parallel()
+    exc = excinfo.value
+    if backend == "loky" and isinstance(exc, TerminatedWorkerError):
+        # The recursion exception can itself cause an error when pickling it to
+        # be send back to the parent process. In this case the worker crashes
+        # but the original traceback is still printed on stderr. This could be
+        # improved but does not seem simple to do and this is is not critical
+        # for users (as long as there is no process or thread bomb happening).
+        pytest.xfail("Loky worker crash when serializing RecursionError")
+    else:
+        assert isinstance(exc, RecursionError)
 
 
 def _run_parallel_sum():
@@ -1578,7 +1563,7 @@ def _parent_max_num_threads_for(child_module, parent_info):
 
 def check_child_num_threads(workers_info, parent_info, num_threads):
     # Check that the number of threads reported in workers_info is consistent
-    # with the expectation. We need to be carefull to handle the cases where
+    # with the expectation. We need to be careful to handle the cases where
     # the requested number of threads is below max_num_thread for the library.
     for child_threadpool_info in workers_info:
         for child_module in child_threadpool_info:
